marktools.BarLine
=================

.. abjad-lineage:: abjad.tools.marktools.BarLine.BarLine.BarLine

.. autoclass:: abjad.tools.marktools.BarLine.BarLine.BarLine

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.marktools.BarLine.BarLine.BarLine.attach
      ~abjad.tools.marktools.BarLine.BarLine.BarLine.bar_line_string
      ~abjad.tools.marktools.BarLine.BarLine.BarLine.command_name
      ~abjad.tools.marktools.BarLine.BarLine.BarLine.detach
      ~abjad.tools.marktools.BarLine.BarLine.BarLine.format_slot
      ~abjad.tools.marktools.BarLine.BarLine.BarLine.lilypond_format
      ~abjad.tools.marktools.BarLine.BarLine.BarLine.start_component
      ~abjad.tools.marktools.BarLine.BarLine.BarLine.storage_format
      ~abjad.tools.marktools.BarLine.BarLine.BarLine.__call__
      ~abjad.tools.marktools.BarLine.BarLine.BarLine.__copy__
      ~abjad.tools.marktools.BarLine.BarLine.BarLine.__eq__
      ~abjad.tools.marktools.BarLine.BarLine.BarLine.__ne__
      ~abjad.tools.marktools.BarLine.BarLine.BarLine.__repr__

Bases
-----

- :py:class:`marktools.LilyPondCommandMark <abjad.tools.marktools.LilyPondCommandMark.LilyPondCommandMark.LilyPondCommandMark>`

- :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.marktools.BarLine.BarLine.BarLine.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.marktools.BarLine.BarLine.BarLine.start_component
   :noindex:

.. autoattribute:: abjad.tools.marktools.BarLine.BarLine.BarLine.storage_format
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.marktools.BarLine.BarLine.BarLine.bar_line_string
   :noindex:

.. autoattribute:: abjad.tools.marktools.BarLine.BarLine.BarLine.command_name
   :noindex:

.. autoattribute:: abjad.tools.marktools.BarLine.BarLine.BarLine.format_slot
   :noindex:

Methods
-------

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.attach
   :noindex:

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.detach
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__call__
   :noindex:

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__copy__
   :noindex:

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__eq__
   :noindex:

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__ne__
   :noindex:

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__repr__
   :noindex:
